pub struct RouterCallPlan {
pub tier: ReasoningTier,
pub disclosure: RouterCallDisclosure,
}Expand description
The tier a Router call is actually made at, plus the disclosure for it.
Fields
tier: ReasoningTierThe concrete tier to place on the Router request.
disclosure: RouterCallDisclosureThe four-sided story, for the receipt.