pub fn validate_role_token(role: &str) -> Result<String, FleetRoleResolveError>Expand description
Validate a role token the same way leaf profiles are validated.
pub fn validate_role_token(role: &str) -> Result<String, FleetRoleResolveError>Validate a role token the same way leaf profiles are validated.