pub struct LeafResult {
pub leaf_id: String,
pub task_id: String,
pub role: Option<String>,
pub profile: Option<String>,
pub status: WorkflowRunStatus,
pub usage: WorkflowUsage,
pub memo_usage: WorkflowMemoUsage,
pub output: Option<String>,
pub artifacts: Vec<String>,
pub schema_error: Option<String>,
}Fields
leaf_id: Stringtask_id: Stringrole: Option<String>Fleet role the leaf was declared to run as, if any (#4177).
profile: Option<String>Fleet roster profile the leaf was declared to run as, if any.
status: WorkflowRunStatususage: WorkflowUsagememo_usage: WorkflowMemoUsageoutput: Option<String>artifacts: Vec<String>schema_error: Option<String>Post-hoc validation failure for the leaf’s structured response.